@@ -1,14 +1,17 @@
 import os
+import subprocess
 import sys
 
-from django.conf import global_settings
 from django.test import TestCase
 from django.core.exceptions import ImproperlyConfigured
 
-from mock import patch
+from unittest.mock import patch
 
 from configurations.importer import ConfigurationImporter
 
+ROOT_DIR = os.path.dirname(os.path.dirname(__file__))
+TEST_PROJECT_DIR = os.path.join(ROOT_DIR, 'test_project')
+
 
 class MainTests(TestCase):
 
@@ -22,10 +25,7 @@ class MainTests(TestCase):
         self.assertTrue(lambda: callable(main.PRISTINE_LAMBDA_SETTING))
         self.assertNotEqual(main.PRISTINE_FUNCTION_SETTING, 5)
         self.assertTrue(lambda: callable(main.PRISTINE_FUNCTION_SETTING))
-        self.assertEqual(main.TEMPLATE_CONTEXT_PROCESSORS,
-                         global_settings.TEMPLATE_CONTEXT_PROCESSORS + (
-                             'tests.settings.base.test_callback',
-                         ))
+        self.assertEqual(main.ALLOWED_HOSTS, ['base'])
         self.assertEqual(main.PRE_SETUP_TEST_SETTING, 6)
         self.assertRaises(AttributeError, lambda: main.POST_SETUP_TEST_SETTING)
         self.assertEqual(main.Test.POST_SETUP_TEST_SETTING, 7)
@@ -67,8 +67,9 @@ class MainTests(TestCase):
         importer = ConfigurationImporter()
         self.assertEqual(importer.module, 'tests.settings.main')
         self.assertEqual(importer.name, 'Test')
-        self.assertEqual(repr(importer),
-                         "<ConfigurationImporter for 'tests.settings.main.Test'>")
+        self.assertEqual(
+            repr(importer),
+            "<ConfigurationImporter for 'tests.settings.main.Test'>")
 
     @patch.dict(os.environ, clear=True,
                 DJANGO_SETTINGS_MODULE='tests.settings.inheritance',
@@ -92,3 +93,58 @@ class MainTests(TestCase):
         importer = ConfigurationImporter(check_options=True)
         self.assertEqual(importer.module, 'tests.settings.main')
         self.assertEqual(importer.name, 'Test')
+
+    def test_configuration_argument_in_cli(self):
+        """
+        Verify that's configuration option has been added to managements
+        commands
+        """
+        proc = subprocess.Popen(['django-cadmin', 'test', '--help'],
+                                stdout=subprocess.PIPE)
+        self.assertIn('--configuration', proc.communicate()[0].decode('utf-8'))
+        proc = subprocess.Popen(['django-cadmin', 'runserver', '--help'],
+                                stdout=subprocess.PIPE)
+        self.assertIn('--configuration', proc.communicate()[0].decode('utf-8'))
+
+    def test_configuration_argument_in_runypy_cli(self):
+        """
+        Verify that's configuration option has been added to managements
+        commands when using the -m entry point
+        """
+        proc = subprocess.Popen(
+            [sys.executable, '-m', 'configurations', 'test', '--help'],
+            stdout=subprocess.PIPE,
+        )
+        self.assertIn('--configuration', proc.communicate()[0].decode('utf-8'))
+        proc = subprocess.Popen(
+            [sys.executable, '-m', 'configurations', 'runserver', '--help'],
+            stdout=subprocess.PIPE,
+        )
+        self.assertIn('--configuration', proc.communicate()[0].decode('utf-8'))
+
+    def test_django_setup_only_called_once(self):
+        proc = subprocess.Popen(
+            [sys.executable, os.path.join(os.path.dirname(__file__),
+                                          'setup_test.py')],
+            stdout=subprocess.PIPE)
+        res = proc.communicate()
+        stdout = res[0].decode('utf-8')
+
+        self.assertIn('setup_1', stdout)
+        self.assertIn('setup_2', stdout)
+        self.assertIn('setup_done', stdout)
+        self.assertEqual(proc.returncode, 0)
+
+    def test_utils_reraise(self):
+        from configurations.utils import reraise
+
+        class CustomException(Exception):
+            pass
+
+        with self.assertRaises(CustomException) as cm:
+            try:
+                raise CustomException
+            except Exception as exc:
+                reraise(exc, "Couldn't setup configuration", None)
+
+        self.assertEqual(cm.exception.args, ("Couldn't setup configuration:   ",))
